within Heatpump_singleSpeed;
model Building
  "Example model with one thermal zone with a radiant floor for Ecobee project"

  package MediumW=Buildings.Media.Water
    "Water medium";

  constant Modelica.Units.SI.Area ASur=208.56045096282995 "External wall area";
  parameter Real unit_leakage_area = 2.8;
  parameter Real stack_coeff = 0.000145;
  parameter Real wind_coeff = 0.000174;

  parameter Modelica.Units.SI.HeatFlowRate QHea_flow_nominal=3073.74
    "Nominal heat flow rate for heating";
  parameter Modelica.Units.SI.MassFlowRate mHea_flow_nominal=QHea_flow_nominal/
      1006/20 "Design air mass flow rate for heating";
  parameter Modelica.Units.SI.HeatFlowRate QCoo_flow_nominal=-5994.71 
    "Nominal heat flow rate for cooling";
  parameter Modelica.Units.SI.MassFlowRate mCoo_flow_nominal=-QCoo_flow_nominal
      /1006/15 "Design air mass flow rate for cooling";
  parameter Modelica.Units.SI.MassFlowRate mCond_flow_nominal = -QCoo_flow_nominal*(1 + 1/3)/1006/10;
  parameter Real TCoolingWT = 16+273.15;
  parameter Real THeatingWT = 50+273.15;
  // Floor slab
  // Ceiling slab
  parameter Modelica.Units.SI.MassFlowRate m_flow_nominal=max(mHea_flow_nominal, mCoo_flow_nominal)
    "Nominal mass flow rate";
  parameter Modelica.Units.SI.PressureDifference dp_nominal=50
    "Nominal pressure difference";

  Buildings.Utilities.IO.SignalExchange.Read read_TRoomTemp(
    y(unit="K"),
    description="ZoneTemp",
    KPIs=Buildings.Utilities.IO.SignalExchange.SignalTypes.SignalsForKPIs.AirZoneTemperature)
    annotation (Placement(transformation(extent={{100,6},{120,26}})));
  Buildings.Utilities.IO.SignalExchange.Overwrite overwrite_CoolingStatus(u(unit="1"),
      description="set Coolingstatus")
    annotation (Placement(transformation(extent={{-102,130},{-82,150}})));
  Buildings.ThermalZones.EnergyPlus_9_6_0.ThermalZone
                                                zon(
    zoneName="living zone",
    redeclare package Medium = Buildings.Media.Air,
    T_start=296.15,
    nPorts=4)
    "Thermal zone"
    annotation (Placement(transformation(extent={{-54,-56},{-14,-16}})));
  inner Buildings.ThermalZones.EnergyPlus_9_6_0.Building
                                                   building(
    idfName=Modelica.Utilities.Files.loadResource(
        "/home/jermy/VSCodeProjects/openmodelica/370/Heatpump_singleSpeed/bldg0000370-up00.idf"),
    epwName=Modelica.Utilities.Files.loadResource("/home/jermy/VSCodeProjects/openmodelica/370/weather/G1201030.epw"),
    weaName=Modelica.Utilities.Files.loadResource("/home/jermy/VSCodeProjects/openmodelica/370/weather/G1201030.mos"),
    usePrecompiledFMU=false,
    computeWetBulbTemperature=false)
    "Building model"
    annotation (Placement(transformation(extent={{-436,-6},{-416,14}})));

  Buildings.Fluid.Sensors.TemperatureTwoPort senTem(redeclare package Medium =
        Buildings.Media.Air, m_flow_nominal=1)
    annotation (Placement(transformation(extent={{-40,-180},{-20,-160}})));
  Modelica.Blocks.Sources.Constant qIntGai(each k=0)
    "Internal heat gains, set to zero because these are modeled in EnergyPlus"
    annotation (Placement(transformation(extent={{-136,-30},{-116,-10}})));
  Buildings.Utilities.IO.SignalExchange.Read read_TRadTemp1(
    y(unit="K"),
    description="ZoneRadTemp",
    KPIs=Buildings.Utilities.IO.SignalExchange.SignalTypes.SignalsForKPIs.RadiativeZoneTemperature)
    annotation (Placement(transformation(extent={{66,-62},{86,-42}})));

parameter String schedcsv=Modelica.Utilities.Files.loadResource("/home/jermy/VSCodeProjects/openmodelica/370/Heatpump_singleSpeed/bldg0000370-up00.txt");

  Buildings.Controls.OBC.CDL.Continuous.Hysteresis hys_cooling(uLow=25 + 273.15,
      uHigh=27 + 273.15)
    annotation (Placement(transformation(extent={{-230,118},{-194,154}})));
  Buildings.Controls.OBC.CDL.Continuous.Hysteresis hys_heating(uLow=19 + 273.15,
      uHigh=21 + 273.15)
    annotation (Placement(transformation(extent={{-232,54},{-196,90}})));
  Modelica.Blocks.Math.BooleanToReal booleanToReal(realTrue=-1.0, realFalse=0.0)
    annotation (Placement(transformation(extent={{-166,128},{-146,148}})));
  Modelica.Blocks.Math.RealToInteger realToInteger
    annotation (Placement(transformation(extent={{190,100},{210,120}})));
  Modelica.Blocks.Math.BooleanToReal booleanToReal1(realTrue=1.0, realFalse=0.0)
    annotation (Placement(transformation(extent={{-106,62},{-86,82}})));
  Modelica.Blocks.Logical.Not not1
    annotation (Placement(transformation(extent={{-164,62},{-144,82}})));
  Buildings.Utilities.IO.SignalExchange.Overwrite overwrite_HeatingStatus(u(unit=
          "1"), description="set HeatingStatus")
    annotation (Placement(transformation(extent={{-40,62},{-20,82}})));
  Infiltration_Control infiltration_control(
    A_L=ASur*unit_leakage_area,
    C_s=stack_coeff,
    C_w=wind_coeff)
    annotation (Placement(transformation(extent={{-504,128},{-440,166}})));
  Fan_Control fan_Control(cooling_nominal_flow = mCoo_flow_nominal, heating_nominal_flow = mHea_flow_nominal)
    annotation (Placement(transformation(extent={{-222,-70},{-202,-50}})));
  Buildings.Fluid.Movers.FlowControlled_m_flow fan(
    redeclare package Medium = Buildings.Media.Air,
    m_flow_nominal = m_flow_nominal,
    dp_nominal = 50,
    per(pressure(V_flow={0,m_flow_nominal,2*m_flow_nominal}/1.2, dp={2*
            dp_nominal,dp_nominal,0})),
    energyDynamics=Modelica.Fluid.Types.Dynamics.SteadyState,
    addPowerToMedium=false)                                    "Fan"
    annotation (Placement(transformation(extent={{-118,-118},{-98,-98}})));
  Modelica.Blocks.Sources.RealExpression realExpression2(y=-1)
    annotation (Placement(transformation(extent={{292,-180},{312,-160}})));
  Modelica.Blocks.Sources.Constant qIntGai1(each k=0)
    "Internal heat gains, set to zero because these are modeled in EnergyPlus"
    annotation (Placement(transformation(extent={{-178,-40},{-158,-20}})));
  Modelica.Blocks.Sources.Constant qIntGai2(each k=0)
    "Internal heat gains, set to zero because these are modeled in EnergyPlus"
    annotation (Placement(transformation(extent={{-104,-80},{-84,-60}})));
  Buildings.Fluid.Sources.Outside out(redeclare package Medium =
        Buildings.Media.Air, nPorts=1)
    annotation (Placement(transformation(extent={{36,-120},{56,-100}})));
  Buildings.Utilities.IO.SignalExchange.Read read_Cooling_Power(
    y(unit="W"),
    description="CoolingPower",
    KPIs=Buildings.Utilities.IO.SignalExchange.SignalTypes.SignalsForKPIs.ElectricPower)
    annotation (Placement(transformation(extent={{222,-84},{242,-64}})));
  Modelica.Blocks.Sources.RealExpression realExpression1(y=hea.Q_flow)
    annotation (Placement(transformation(extent={{166,24},{186,44}})));
  Buildings.Utilities.IO.SignalExchange.Read read_auxHeat(
    y(unit="W"),
    description="aux_heat",
    KPIs=Buildings.Utilities.IO.SignalExchange.SignalTypes.SignalsForKPIs.ElectricPower)
    annotation (Placement(transformation(extent={{218,24},{238,44}})));
  Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C=zon.V*1.2
        *1006*20);
  Modelica.Blocks.Logical.Switch switch3
    annotation (Placement(transformation(extent={{-214,-114},{-194,-94}})));
  Modelica.Blocks.Logical.Switch switch2
    annotation (Placement(transformation(extent={{50,118},{70,138}})));
  Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=-0.5)
    annotation (Placement(transformation(extent={{-8,162},{12,182}})));
  Modelica.Blocks.Nonlinear.FixedDelay fixedDelay(delayTime=30)
    annotation (Placement(transformation(extent={{-176,-90},{-156,-70}})));
  Modelica.Blocks.Nonlinear.FixedDelay fixedDelay2(delayTime=30)
    annotation (Placement(transformation(extent={{48,160},{68,180}})));
  Modelica.Blocks.Logical.GreaterThreshold greaterThreshold1(threshold=0.5)
    annotation (Placement(transformation(extent={{-218,-36},{-198,-16}})));
  Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold=0.5)
    annotation (Placement(transformation(extent={{22,42},{42,62}})));
  Modelica.Blocks.Nonlinear.FixedDelay fixedDelay1(delayTime=30)
    annotation (Placement(transformation(extent={{88,92},{108,112}})));
  Modelica.Blocks.Logical.Switch switch1
    annotation (Placement(transformation(extent={{166,70},{186,90}})));
  Modelica.Blocks.Sources.RealExpression realExpression3(y=sinSpeDX1.P)
    annotation (Placement(transformation(extent={{168,-84},{188,-64}})));
  Modelica.Blocks.Sources.RealExpression realExpression4(y=fan.P)
    annotation (Placement(transformation(extent={{164,-26},{184,-6}})));
  Buildings.Utilities.IO.SignalExchange.Read read_FanPower(
    y(unit="W"),
    description="FanPower",
    KPIs=Buildings.Utilities.IO.SignalExchange.SignalTypes.SignalsForKPIs.ElectricPower)
    annotation (Placement(transformation(extent={{220,-28},{240,-8}})));
  // Buildings.BoundaryConditions.WeatherData.ReaderTMY3 weaDat(filNam="/megabop/products/testcases/118103/weather/USA_MD_Baltimore-Washington.Intl.AP.724060_TMY3.mos",
  // TDryBulSou=Buildings.BoundaryConditions.Types.DataSource.File)
  // annotation (Placement(transformation(extent={{-386,190},{-366,210}})));
  Buildings.BoundaryConditions.WeatherData.Bus weaBus annotation (Placement(
      transformation(extent={{-370,216},{-330,256}}), iconTransformation(
        extent={{-572,194},{-552,214}})));
  Buildings.Fluid.Sources.MassFlowSource_WeatherData bou1(
  redeclare package Medium = Buildings.Media.Air,
  use_m_flow_in=true,
  m_flow=0.3,
  nPorts=1)
  annotation (Placement(transformation(extent={{-430,100},{-410,120}})));
  Buildings.Fluid.HeatExchangers.DXCoils.AirCooled.SingleSpeed sinSpeDX1(
    redeclare package Medium = Buildings.Media.Air,
    dp_nominal = dp_nominal,
    datCoi = datCoi,
    T_start = datCoi.sta[1].nomVal.TEvaIn_nominal,
    show_T = true,
    from_dp = true,
    energyDynamics = Modelica.Fluid.Types.Dynamics.FixedInitial)
    "Single speed DX coil"
    annotation (Placement(transformation(extent = {{-8, -236}, {26, -202}})));
  Modelica.Blocks.Math.Abs abs1
    annotation (Placement(transformation(extent={{238,138},{258,158}})));
  Modelica.Blocks.Math.IntegerToBoolean integerToBoolean
    annotation (Placement(transformation(extent={{230,94},{250,114}})));
  parameter Buildings.Fluid.HeatExchangers.DXCoils.AirCooled.Data.Generic.DXCoil datCoi(sta={
        Buildings.Fluid.HeatExchangers.DXCoils.AirCooled.Data.Generic.BaseClasses.Stage(
        spe=1800/60,
        nomVal=
          Buildings.Fluid.HeatExchangers.DXCoils.AirCooled.Data.Generic.BaseClasses.NominalValues(
          Q_flow_nominal=QCoo_flow_nominal,
          COP_nominal=3,
          SHR_nominal=0.8,
          m_flow_nominal=mCoo_flow_nominal),
        perCur=
          Buildings.Fluid.HeatExchangers.DXCoils.AirCooled.Examples.PerformanceCurves.Curve_II())},
      nSta=1)                                                                                                    "Coil data"
    annotation (Placement(transformation(extent={{114,156},{134,176}})));
  Buildings.Fluid.HeatPumps.EquationFitReversible heaPum(
    redeclare package Medium1 = Buildings.Media.Air,
    redeclare package Medium2 = Buildings.Media.Air,
    allowFlowReversal1=true,
    allowFlowReversal2=true,
    from_dp1=true,
    linearizeFlowResistance1=true,
    from_dp2=true,
    linearizeFlowResistance2=true,
    per=per)
    annotation (Placement(transformation(extent={{76,-258},{116,-210}})));
  Buildings.Fluid.Sensors.TemperatureTwoPort senTem1(redeclare package Medium
      = Buildings.Media.Air, m_flow_nominal=1)
    annotation (Placement(transformation(extent={{40,-228},{60,-208}})));
  Buildings.Fluid.HeatExchangers.HeaterCooler_u
                 hea(
    redeclare package Medium = Buildings.Media.Air,
    m_flow_nominal=mHea_flow_nominal,
    dp_nominal=100,
    energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial,
    Q_flow_nominal=mHea_flow_nominal*40*1000)
                                   "Heater"
    annotation (Placement(transformation(extent={{136,-226},{156,-206}})));
  auxHeater_Ctrl auxHeater_Ctrl1
    annotation (Placement(transformation(extent={{208,62},{228,82}})));
  Modelica.Blocks.Logical.LessThreshold lessThreshold1(threshold=-5 + 273)
    annotation (Placement(transformation(extent={{-308,-212},{-288,-192}})));
  Buildings.Fluid.Sources.MassFlowSource_WeatherData Ambient_side_source(
    redeclare package Medium = Buildings.Media.Air,
    use_m_flow_in=false,
    m_flow=mCond_flow_nominal,
    nPorts=1) "Boundary condition"
    annotation (Placement(transformation(extent={{-144,-268},{-124,-248}})));
  Buildings.Fluid.Sources.Outside Ambient_side_sink(redeclare package Medium =
        Buildings.Media.Air, nPorts=1) "Boundary condition"
    annotation (Placement(transformation(extent={{-86,-250},{-66,-230}})));
  parameter airsourcecurve per(hea(
      TRefLoa=20 + 273.15,
      TRefSou=8 + 273.15,
      Q_flow=QHea_flow_nominal,
      P=5000,
      mSou_flow=2,
      mLoa_flow=mHea_flow_nominal,
      coeQ={-4.23,-1.24,6.28,0.01,0.08},
      coeP={-5.55,5.08,1.01,-0.04,0.00}), coo(
      mLoa_flow=mCoo_flow_nominal,
      mSou_flow=2,
      TRefSou=30 + 273.15,
      TRefLoa=24 + 273.15,
      Q_flow=QCoo_flow_nominal,
      P=-QCoo_flow_nominal/2.5,
      coeQ={-5.79235417,9.83800467,-3.19795605,0.32498894,0.043752306918433},
      coeP={-6.37109639,1.27560526,5.81780490,0.03132874,-0.082990443216406}))
    annotation (Placement(transformation(extent={{-158,182},{-138,202}})));
  Modelica.Blocks.Sources.RealExpression realExpression5(y=32.22 + 273.15)
    annotation (Placement(transformation(extent={{6,-156},{26,-136}})));
  defrost_ctrl_v2 defrost_ctrl_v2_1
    annotation (Placement(transformation(extent={{264,-210},{284,-190}})));
  Modelica.Blocks.Logical.Switch switch4
    annotation (Placement(transformation(extent={{332,-210},{352,-190}})));
  Modelica.Blocks.Math.IntegerToReal    integerToReal
    annotation (Placement(transformation(extent={{342,54},{362,74}})));
  Modelica.Blocks.Math.RealToInteger realToInteger1
    annotation (Placement(transformation(extent={{382,-232},{402,-212}})));
  Modelica.Blocks.Logical.LessThreshold lessThreshold2(threshold=2 + 273)
    annotation (Placement(transformation(extent={{-288,-252},{-268,-232}})));
  Buildings.Controls.OBC.CDL.Logical.FallingEdge falEdg
    annotation (Placement(transformation(extent={{318,-270},{338,-250}})));
  Buildings.Controls.OBC.CDL.Logical.TrueFalseHold truFalHol(trueHoldDuration=1
        *60, falseHoldDuration=60)
    annotation (Placement(transformation(extent={{350,-370},{370,-350}})));
  noeventcontrol noeventcontrol1
    annotation (Placement(transformation(extent={{180,-286},{200,-266}})));
  Modelica.Blocks.Sources.RealExpression realExpression6(y=heaPum.P)
    annotation (Placement(transformation(extent={{166,-112},{186,-92}})));
  Buildings.Utilities.IO.SignalExchange.Read read_heating_Power1(
    y(unit="W"),
    description="HeatingPower",
    KPIs=Buildings.Utilities.IO.SignalExchange.SignalTypes.SignalsForKPIs.ElectricPower)
    annotation (Placement(transformation(extent={{224,-114},{244,-94}})));
  Buildings.Utilities.IO.SignalExchange.Read read_TAmb(
    y(unit="K"),
    description="T_amb",
    KPIs=Buildings.Utilities.IO.SignalExchange.SignalTypes.SignalsForKPIs.AirZoneTemperature)
    annotation (Placement(transformation(extent={{-408,42},{-388,62}})));
equation
  //connect(CoolingSetPoint.y, masFloSouCoo.T_in) annotation (Line(points={{-81.7,
    //      136},{-60,136},{-60,94},{-40,94}}, color={0,0,127}));

    //masFloSouCoo.T_in = TCoolingWT;
   // hea.TSet = THeatingWT;

 //connect(HeatingSetPoint1.y, hea.TSet) annotation (Line(points={{-141.7,-166},{
         // -50,-166},{-50,-172},{-42,-172}}, color={0,0,127}));
  connect(fixedDelay1.y, switch1.u1) annotation (Line(points={{109,102},{134,
          102},{134,88},{164,88}}, color={0,0,127}));
  connect(greaterThreshold.y, switch1.u2) annotation (Line(points={{43,52},{102,
          52},{102,80},{164,80}},     color={255,0,255}));
  connect(overwrite_HeatingStatus.y, switch1.u3) annotation (Line(points={{-19,72},
          {164,72}},                                           color={0,0,127}));
  connect(overwrite_HeatingStatus.y, fixedDelay1.u) annotation (Line(points={{-19,72},
          {32,72},{32,102},{86,102}},          color={0,0,127}));
  connect(overwrite_HeatingStatus.y, greaterThreshold.u) annotation (Line(
        points={{-19,72},{-3.5,72},{-3.5,52},{20,52}}, color={0,0,127}));
  connect(overwrite_CoolingStatus.y, fixedDelay2.u) annotation (Line(points={{-81,
          140},{-64,140},{-64,214},{34,214},{34,170},{46,170}}, color={0,0,
          127}));
  connect(overwrite_CoolingStatus.y, lessThreshold.u) annotation (Line(points={{
          -81,140},{-46,140},{-46,172},{-10,172}}, color={0,0,127}));
  connect(overwrite_CoolingStatus.y, switch2.u3) annotation (Line(points={{-81,140},
          {-16,140},{-16,120},{48,120}}, color={0,0,127}));
  connect(lessThreshold.y, switch2.u2) annotation (Line(points={{13,172},{30,
          172},{30,128},{48,128}}, color={255,0,255}));
  connect(fixedDelay2.y, switch2.u1) annotation (Line(points={{69,170},{76,
          170},{76,168},{84,168},{84,144},{42,144},{42,136},{48,136}}, color=
          {0,0,127}));
  connect(fan_Control.y, greaterThreshold1.u) annotation (Line(points={{
          -201.2,-59},{-220,-59},{-220,-26}}, color={0,0,127}));
  connect(greaterThreshold1.y, switch3.u2) annotation (Line(points={{-197,-26},
          {-186,-26},{-186,-100},{-206,-100},{-206,-104},{-216,-104}},
                                                                     color={
          255,0,255}));
  connect(heatCapacitor.port, zon.heaPorAir) annotation (Line(points={{-484,
          94},{-484,-8},{-34,-8},{-34,-36}}, color={191,0,0}));
  connect(zon.TAir, read_TRoomTemp.u) annotation (Line(points={{-13,-18},{70,-18},
          {70,16},{98,16}},color={0,0,127}));
  connect(fan_Control.y, fixedDelay.u) annotation (Line(points={{-201.2,-59},
          {-189.6,-59},{-189.6,-80},{-178,-80}}, color={0,0,127}));
  connect(zon.TRad, read_TRadTemp1.u) annotation (Line(points={{-13,-22},{48,-22},
          {48,-52},{64,-52}},                        color={0,0,127}));
  connect(hys_cooling.y, booleanToReal.u) annotation (Line(points={{-190.4,136},
          {-178.2,136},{-178.2,138},{-168,138}}, color={255,0,255}));
  connect(booleanToReal.y, overwrite_CoolingStatus.u) annotation (Line(points={{-145,
          138},{-126,138},{-126,140},{-104,140}}, color={0,0,127}));
  connect(zon.TAir, hys_cooling.u) annotation (Line(points={{-13,-18},{-4,-18},{
          -4,18},{-22,18},{-22,176},{-262,176},{-262,136},{-233.6,136}},  color=
         {0,0,127}));
  connect(hys_heating.y, not1.u) annotation (Line(points={{-192.4,72},{-166,72}},
                                color={255,0,255}));
  connect(not1.y, booleanToReal1.u) annotation (Line(points={{-143,72},{-108,72}},
                               color={255,0,255}));
  connect(booleanToReal1.y, overwrite_HeatingStatus.u) annotation (Line(points={{-85,72},
          {-42,72}},                             color={0,0,127}));
  connect(overwrite_CoolingStatus.y, fan_Control.Cooling_u) annotation (Line(points={{-81,140},
          {-81,168},{-260,168},{-260,-56.4},{-223.2,-56.4}},      color={0,0,
          127}));
  connect(overwrite_HeatingStatus.y, fan_Control.Heating_u) annotation (Line(
        points={{-19,72},{-8,72},{-8,96},{-314,96},{-314,-68},{-258,-68},{-258,
          -64.6},{-223,-64.6}}, color={0,0,127}));
  connect(zon.TAir, hys_heating.u) annotation (Line(points={{-13,-18},{-8,-18},
          {-8,24},{-244,24},{-244,72},{-235.6,72}}, color={0,0,127}));
  connect(zon.ports[1], fan.port_a) annotation (Line(points={{-35.5,-55.1},{
          -142,-55.1},{-142,-108},{-118,-108}},
                                    color={0,127,255}));
  connect(fan.port_b, senTem.port_a) annotation (Line(points={{-98,-108},{-84,-108},
        {-84,-170},{-40,-170}}, color={0,127,255}));
  // connect(fan_Control.y, fan.y) annotation (Line(points={{-201.2,-59},{-166,-59},
  //         {-166,-96},{-108,-96}},   color={0,0,127}));
  connect(switch3.y, fan.m_flow_in) annotation (Line(points={{-193,-104},{-148,
          -104},{-148,-96},{-108,-96}},
                                  color={0,0,127}));
  connect(fixedDelay.y, switch3.u3) annotation (Line(points={{-155,-80},{-162,
          -80},{-162,-138},{-236,-138},{-236,-112},{-216,-112}}, color={0,0,
          127}));
  connect(fan_Control.y, switch3.u1) annotation (Line(points={{-201.2,-59},{
          -200,-59},{-200,-88},{-224,-88},{-224,-96},{-216,-96}},   color={0,
          0,127}));
  connect(qIntGai.y, zon.qGai_flow[1]) annotation (Line(points={{-115,-20},{-86,
          -20},{-86,-26.6667},{-56,-26.6667}}, color={0,0,127}));
  connect(qIntGai1.y, zon.qGai_flow[2]) annotation (Line(points={{-157,-30},{-108,
          -30},{-108,-26},{-56,-26}},      color={0,0,127}));
  connect(qIntGai2.y, zon.qGai_flow[3]) annotation (Line(points={{-83,-70},{-70,
          -70},{-70,-25.3333},{-56,-25.3333}}, color={0,0,127}));
  connect(zon.ports[2], out.ports[1]) annotation (Line(points={{-34.5,-55.1},{
          -34.5,-88},{50,-88},{50,-98},{56,-98},{56,-110}},
                                                    color={0,127,255}));
  connect(building.weaBus, out.weaBus) annotation (Line(
      points={{-416,4},{-354,4},{-354,10},{16,10},{16,-109.8},{36,-109.8}},
      color={255,204,51},
      thickness=0.5));
  // connect(heaPum.P, read_CoolingPower.u) annotation (Line(points={{-95.4,-213.58},
  //         {58,-213.58},{58,-238},{98,-238}}, color={0,0,127}));
  connect(realExpression1.y, read_auxHeat.u)
    annotation (Line(points={{187,34},{216,34}}, color={0,0,127}));
  // connect(weaDat.weaBus, weaBus) annotation (Line(
  //   points={{-366,200},{-366,217},{-350,217},{-350,236}},
  //   color={255,204,51},
  //   thickness=0.5), Text(
  //   string="%second",
  //   index=1,
  //   extent={{-3,6},{-3,6}},
  //   horizontalAlignment=TextAlignment.Right));
  connect(building.weaBus, weaBus);
  connect(weaBus.TDryBul, infiltration_control.Tamb) annotation (Line(
    points={{-350,236},{-348,236},{-348,326},{-536,326},{-536,153.84},{-507.84,
        153.84}},
    color={255,204,51},
    thickness=0.5), Text(
    string="%first",
    index=-1,
    extent={{-6,3},{-6,3}},
    horizontalAlignment=TextAlignment.Right));
  connect(weaBus.winSpe, infiltration_control.WinSpe) annotation (Line(
    points={{-350,236},{-432,236},{-432,264},{-556,264},{-556,138.26},{-507.2,
        138.26}},
    color={255,204,51},
    thickness=0.5), Text(
    string="%first",
    index=-1,
    extent={{-6,3},{-6,3}},
    horizontalAlignment=TextAlignment.Right));
  connect(zon.TAir, infiltration_control.T_zon) annotation (Line(points={{-13,-18},
        {-13,112},{-534,112},{-534,147},{-507.2,147}}, color={0,0,127}));
  connect(infiltration_control.y, bou1.m_flow_in) annotation (Line(points={{-437.44,
        148.9},{-437.44,132.45},{-430,132.45},{-430,118}}, color={0,0,127}));
  connect(building.weaBus, bou1.weaBus) annotation (Line(
    points={{-416,4},{-438,4},{-438,110.2},{-430,110.2}},
    color={255,204,51},
    thickness=0.5));
  connect(bou1.ports[1], zon.ports[3]) annotation (Line(points={{-410,110},{-60,
          110},{-60,-68},{-33.5,-68},{-33.5,-55.1}},
                                                   color={0,127,255}));

  connect(realExpression3.y, read_Cooling_Power.u)
    annotation (Line(points={{189,-74},{220,-74}}, color={0,0,127}));
  connect(realExpression4.y, read_FanPower.u) annotation (Line(points={{185,-16},
          {202,-16},{202,-18},{218,-18}},              color={0,0,127}));
  connect(switch2.y, abs1.u) annotation (Line(points={{71,128},{152,128},{152,
          148},{236,148}}, color={0,0,127}));
  connect(abs1.y, realToInteger.u) annotation (Line(points={{259,148},{274,148},
          {274,128},{174,128},{174,112},{188,112},{188,110}}, color={0,0,127}));
  connect(realToInteger.y, integerToBoolean.u) annotation (Line(points={{211,
          110},{220,110},{220,104},{228,104}}, color={255,127,0}));
  connect(integerToBoolean.y, sinSpeDX1.on) annotation (Line(points={{251,104},
          {264,104},{264,98},{278,98},{278,-162},{-158,-162},{-158,-213},{-6,-213}},   color={255,0,255}));
  connect(weaBus.TDryBul, sinSpeDX1.TConIn) annotation (Line(points = {{-350, 236}, {-348, 236}, {-348, 88}, {-204, 88}, {-204, -222}, {-6, -222}}, color = {255, 204, 51}, thickness = 0.5));
  connect(senTem.port_b, sinSpeDX1.port_a) annotation (Line(points={{-20,-170},
          {-20, -197.5}, {-4, -197.5}, {-4, -227}}, color={0,127,255}));
  connect(sinSpeDX1.port_b, senTem1.port_a) annotation (Line(points={{30,-227},
          {30,-218},{40,-218}}, color={0,127,255}));
  connect(senTem1.port_b, heaPum.port_a1) annotation (Line(points={{60,-218},{
          68,-218},{68,-219.6},{76,-219.6}}, color={0,127,255}));
  connect(heaPum.port_b1, hea.port_a) annotation (Line(points={{116,-219.6},{
          127,-219.6},{127,-216},{136,-216}}, color={0,127,255}));
  connect(hea.port_b, zon.ports[4]) annotation (Line(points={{156,-216},{160,
          -216},{160,-74},{-42,-74},{-42,-55.1},{-32.5,-55.1}}, color={0,127,
          255}));
  connect(switch1.y, auxHeater_Ctrl1.thermostat_in) annotation (Line(points={{
          187,80},{198,80},{198,77.8},{207,77.8}}, color={0,0,127}));
  connect(auxHeater_Ctrl1.Heater, hea.u) annotation (Line(points={{229,68.8},{
          250,68.8},{250,-118},{126,-118},{126,-210},{134,-210}}, color={0,0,
          127}));
  connect(weaBus.TDryBul, lessThreshold1.u) annotation (Line(
      points={{-350,236},{-348,236},{-348,-202},{-310,-202},{-310,-202}},
      color={255,204,51},
      thickness=0.5), Text(
      string="%first",
      index=-1,
      extent={{-3,6},{-3,6}},
      horizontalAlignment=TextAlignment.Right));
  connect(lessThreshold1.y, auxHeater_Ctrl1.Amb_sig) annotation (Line(points={{
          -287,-202},{188,-202},{188,70},{207.4,70}}, color={255,0,255}));
  connect(building.weaBus, Ambient_side_source.weaBus) annotation (Line(
      points={{-416,4},{-402,4},{-402,0},{-318,0},{-318,-264},{-144,-264},{-144,
          -257.8}},
      color={255,204,51},
      thickness=0.5));
  connect(Ambient_side_source.ports[1], heaPum.port_a2) annotation (Line(points=
         {{-124,-258},{26,-258},{26,-264},{164,-264},{164,-248.4},{116,-248.4}},
        color={0,127,255}));
  connect(building.weaBus, Ambient_side_sink.weaBus) annotation (Line(
      points={{-416,4},{-252,4},{-252,-239.8},{-86,-239.8}},
      color={255,204,51},
      thickness=0.5));
  connect(Ambient_side_sink.ports[1], heaPum.port_b2) annotation (Line(points={
          {-66,-240},{5,-240},{5,-248.4},{76,-248.4}}, color={0,127,255}));
  connect(realExpression5.y, heaPum.TSet) annotation (Line(points={{27,-146},{
          50,-146},{50,-212.4},{73.2,-212.4}}, color={0,0,127}));
  connect(defrost_ctrl_v2_1.y, switch4.u2) annotation (Line(points={{284.6,-197.4},
          {306.3,-197.4},{306.3,-200},{330,-200}}, color={255,0,255}));
  connect(auxHeater_Ctrl1.heat_pump, defrost_ctrl_v2_1.HP_on) annotation (Line(
        points={{229,75.8},{250,75.8},{250,-195.6},{263.2,-195.6}}, color={255,
          127,0}));
  connect(auxHeater_Ctrl1.heat_pump, integerToReal.u) annotation (Line(points={
          {229,75.8},{282.5,75.8},{282.5,64},{340,64}}, color={255,127,0}));
  connect(integerToReal.y, switch4.u3) annotation (Line(points={{363,64},{372,
          64},{372,-154},{324,-154},{324,-208},{330,-208}}, color={0,0,127}));
  connect(switch4.y, realToInteger1.u) annotation (Line(points={{353,-200},{360,
          -200},{360,-222},{380,-222}}, color={0,0,127}));
  connect(realToInteger1.y, heaPum.uMod) annotation (Line(points={{403,-222},{
          424,-222},{424,-184},{66,-184},{66,-234},{74,-234}}, color={255,127,0}));
  connect(realExpression2.y, switch4.u1) annotation (Line(points={{313,-170},{
          313,-181},{330,-181},{330,-192}}, color={0,0,127}));
  connect(weaBus.TDryBul, lessThreshold2.u) annotation (Line(
      points={{-350,236},{-350,-242},{-290,-242}},
      color={255,204,51},
      thickness=0.5), Text(
      string="%first",
      index=-1,
      extent={{-6,3},{-6,3}},
      horizontalAlignment=TextAlignment.Right));
  connect(lessThreshold2.y, defrost_ctrl_v2_1.Amb) annotation (Line(points={{-267,
          -242},{-42,-242},{-42,-334},{218,-334},{218,-200.4},{263.2,-200.4}},
        color={255,0,255}));
  connect(falEdg.y, truFalHol.u) annotation (Line(points={{340,-260},{340,-360},
          {348,-360}}, color={255,0,255}));
  connect(heaPum.P, noeventcontrol1.Power) annotation (Line(points={{118,
          -234.48},{146,-234.48},{146,-276.4},{179.2,-276.4}}, color={0,0,127}));
  connect(noeventcontrol1.y, falEdg.u) annotation (Line(points={{196.6,-276},{
          308,-276},{308,-260},{316,-260}}, color={255,0,255}));
  connect(truFalHol.y, defrost_ctrl_v2_1.reset) annotation (Line(points={{372,
          -360},{380,-360},{380,-240},{252,-240},{252,-205.4},{263,-205.4}},
        color={255,0,255}));
  connect(realExpression6.y, read_heating_Power1.u) annotation (Line(points={{
          187,-102},{187,-104},{222,-104}}, color={0,0,127}));
  connect(weaBus.TDryBul, read_TAmb.u) annotation (Line(
      points={{-350,236},{-350,76},{-416,76},{-416,52},{-410,52}},
      color={255,204,51},
      thickness=0.5), Text(
      string="%first",
      index=-1,
      extent={{6,3},{6,3}},
      horizontalAlignment=TextAlignment.Left));
annotation(
    Diagram(coordinateSystem(extent = {{-560, 340}, {420, -380}})));
end Building;